@@ -103,7 +103,7 @@ def __createUsers(session,users,groups,defaultpassword = None):
         user = session.query(PPSsuser).filter(PPSsuser.username == uname).first()
         if not user:
             user = PPSsuser(username = uname)
-            if upassword or defaultpassword:
+            if upassword:
                 user.setPassword(upassword)
             elif defaultpassword:
                 user.setPassword(defaultpassword)
@@ -218,7 +218,7 @@ class PPSsuser(Base,commonTable):
     insertdt        = Column(DateTime,default=datetime.now)
     updatedt        = Column(DateTime,default=datetime.now,onupdate=datetime.now)
     lastlogin       = Column(DateTime)
-    enabled         = Column(Integer,default=1)
+    enabled         = Column(Integer,default=1) # 0 disabled, 1 active, -1 need activation
     magicnumber     = Column(Text(),default=uuid.uuid5(uuid.uuid4(),"bidibibodibibu" ).hex )   #Conf.saltforhash
     createdby       = Column(Integer)
     disabledby      = Column(Integer)
@@ -248,10 +248,14 @@ class PPSsuser(Base,commonTable):
     def passwordExpired(self,now = None):
         if now is None:
             now = datetime.now()
+        l.debug("user:{},now:{},expire:{},res:{}".format(self.username,now,self.passwordexpire,self.passwordexpire is None or self.passwordexpire>now))
         return not (self.passwordexpire is None or self.passwordexpire>now)
 
     def getPrincipals(self,expired=False):
-        return   [str("g:"+group.name ) for group in self.groups  ] 
+        if expired:
+            return ['ppss_auth:changepassword']
+        else:
+            return [str("g:"+group.name ) for group in self.groups  ] 
 
     def todict(self):
         return { "id": self.id, "username":self.username,"enabled":self.enabled}
