@@ -278,12 +278,14 @@ class AuthController():
                 if res:
                     user.setPassword(newpassword)
                     retdict['msg'] = __(self.request,"Password updated.")
+                    l.info("password upadated for user '{}'".format(user.username))
                 else:
                     retdict['res']=False
                     retdict['msg'] = res.getMsg(self.request)
                     #__(self.request,"New password doesn't match constraints." )
+                    l.info("password upadated failed for user '{}'".format(user.username))
 
-                l.info("password upadated for user '{}'".format(res.username))
+                
                 
                 #TODO: execute fake login with post login redirect?
             else:
